@@ -3,9 +3,16 @@ use strict;
 use Chart::Gnuplot;
 
 # Data in Perl arrays
-my @x = (0 .. 20);
-my @y = (-10 .. 10);
-my @z = map {rand()} @x;
+my (@x, @y, @z) = ();
+for (my $x = -5; $x < 5; $x += 0.02)
+{
+	my $y = sin($x*3);
+	my $z = cos($x*3);
+
+	push(@x, $x);
+	push(@y, $y);
+	push(@z, $z);
+}
 
 my $chart = Chart::Gnuplot->new(
     output => "gallery/plot3d_1.png",
